Struct SkipWhile
pub struct SkipWhile<St, Fut, F>where
St: Stream,{
stream: St,
f: F,
pending_fut: Option<Fut>,
pending_item: Option<<St as Stream>::Item>,
done_skipping: bool,
}Expand description
Stream for the skip_while method.
Fields
stream: Stf: Fpending_fut: Option<Fut>pending_item: Option<<St as Stream>::Item>done_skipping: boolImplementations
impl<St, Fut, F> SkipWhile<St, Fut, F>
impl<St, Fut, F> SkipWhile<St, Fut, F>
pub fn get_ref(&self) -> &St
pub fn get_ref(&self) -> &St
Acquires a reference to the underlying sink or stream that this combinator is pulling from.
pub fn get_mut(&mut self) -> &mut St
pub fn get_mut(&mut self) -> &mut St
Acquires a mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
pub fn get_pin_mut(self: Pin<&mut SkipWhile<St, Fut, F>>) -> Pin<&mut St>
pub fn get_pin_mut(self: Pin<&mut SkipWhile<St, Fut, F>>) -> Pin<&mut St>
Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
pub fn into_inner(self) -> St
pub fn into_inner(self) -> St
Consumes this combinator, returning the underlying sink or stream.
Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.